/** 1. Filter out proteome sequence belonging to 'supercontig' */
/** 2. Filter proteome to keep only the longest isoform */

process FILTER_SUPERCONTIG {
    input:
    path proteome

    output:
    path 'proteome_nosupercontig.fasta'

    script:
    """
    awk -f "${baseDir}/scripts/remove_supercontigs.awk" "${proteome}" > 'proteome_nosupercontig.fasta'
    """
}

process SEQUENCE_LENGTH {
    input:
    path proteome

    output:
    path 'protein_lengths.tsv'

    script:
    """
    awk -f "${baseDir}/scripts/protein_lengths.awk" "${proteome}" > 'protein_lengths.tsv'
    """
}

process PROTEOME_LONGEST {
    input:
    path proteome
    path protein_lengths

    output:
    path 'proteome_filtered.fa'

    script:
    """
    awk -f "${baseDir}/scripts/filter_longest.awk" "${protein_lengths}" "${proteome}" > 'records_filtered.list'
    awk -f "${baseDir}/scripts/filter_records_fasta.awk" 'records_filtered.list' "${proteome}" > 'proteome_filtered.fa'
    """
}

workflow FILTER_FASTA {
    take:
    proteome

    main:
    FILTER_SUPERCONTIG(proteome)
    SEQUENCE_LENGTH(FILTER_SUPERCONTIG.out)
    PROTEOME_LONGEST(FILTER_SUPERCONTIG.out, SEQUENCE_LENGTH.out)

    emit:
    lengths = SEQUENCE_LENGTH.out
    proteome = PROTEOME_LONGEST.out
}
